.. image:: ../../imgs/ooipy_banner2.png
  :width: 700
  :alt: OOIPY Logo
  :align: left

OOIPY Demos
===========

This section is under development. Demos can currently be found on GitHub repository

  - ooipy/hydrophone_demo.ipynb
  - ooipy/ctd_demo.ipynb
